# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/rtvpy',
                'doc_host': 'https://Analytics-Raising.github.io',
                'git_url': 'https://github.com/Analytics-Raising/rtvpy',
                'lib_path': 'rtvpy'},
  'syms': { 'rtvpy.handle_missingness': { 'rtvpy.handle_missingness.empty_columns': ( 'Tutorials/missingness.html#empty_columns',
                                                                                      'rtvpy/handle_missingness.py'),
                                          'rtvpy.handle_missingness.empty_columns_with_threshold': ( 'Tutorials/missingness.html#empty_columns_with_threshold',
                                                                                                     'rtvpy/handle_missingness.py'),
                                          'rtvpy.handle_missingness.empty_rows': ( 'Tutorials/missingness.html#empty_rows',
                                                                                   'rtvpy/handle_missingness.py'),
                                          'rtvpy.handle_missingness.remove_empty_columns': ( 'Tutorials/missingness.html#remove_empty_columns',
                                                                                             'rtvpy/handle_missingness.py')},
            'rtvpy.manipulate': { 'rtvpy.manipulate.create_dec_dummies': ( 'Tutorials/manipulate.html#create_dec_dummies',
                                                                           'rtvpy/manipulate.py'),
                                  'rtvpy.manipulate.create_region_district_mapping': ( 'Tutorials/manipulate.html#create_region_district_mapping',
                                                                                       'rtvpy/manipulate.py'),
                                  'rtvpy.manipulate.populate_region_column': ( 'Tutorials/manipulate.html#populate_region_column',
                                                                               'rtvpy/manipulate.py'),
                                  'rtvpy.manipulate.set_row_as_header': ( 'Tutorials/manipulate.html#set_row_as_header',
                                                                          'rtvpy/manipulate.py'),
                                  'rtvpy.manipulate.standardize_district_names': ( 'Tutorials/manipulate.html#standardize_district_names',
                                                                                   'rtvpy/manipulate.py')},
            'rtvpy.variable_decodings': { 'rtvpy.variable_decodings.getMeanings': ( 'Tutorials/getting_meanings.html#getmeanings',
                                                                                    'rtvpy/variable_decodings.py'),
                                          'rtvpy.variable_decodings.get_column_groups': ( 'Tutorials/getting_meanings.html#get_column_groups',
                                                                                          'rtvpy/variable_decodings.py'),
                                          'rtvpy.variable_decodings.get_meanings': ( 'Tutorials/getting_meanings.html#get_meanings',
                                                                                     'rtvpy/variable_decodings.py'),
                                          'rtvpy.variable_decodings.pick_and_add_columns': ( 'Tutorials/getting_meanings.html#pick_and_add_columns',
                                                                                             'rtvpy/variable_decodings.py')},
            'rtvpy.wandb_manager': { 'rtvpy.wandb_manager.load_wandb_artifact': ( 'Wandb/wandb_manager.html#load_wandb_artifact',
                                                                                  'rtvpy/wandb_manager.py'),
                                     'rtvpy.wandb_manager.push_wandb_artifact': ( 'Wandb/wandb_manager.html#push_wandb_artifact',
                                                                                  'rtvpy/wandb_manager.py')}}}
